Index: BOL/Multi_atlas/Utils/atlas0.sh
===================================================================
--- BOL/Multi_atlas/Utils/atlas0.sh	(revision 3736)
+++ BOL/Multi_atlas/Utils/atlas0.sh	(revision 3737)
@@ -134,7 +134,7 @@
       ls -lrt | tail
 # A ADAPTER en fonction de la machine
-      sed -e "s:/prodigfs/ipslfs/dods/:/thredds/fileServer/IPSLFS/:g" tmp$$.$passage >| $htmlopt
+      sed -e "s:/modfs/ipslfs/dods/:/thredds/fileServer/IPSLFS/:g" tmp$$.$passage >| $htmlopt
       \cp -f $htmlopt $OUT_D/
-      PathHtml=`echo $OUT_D/$htmlopt | sed -e 's:/prodigfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'`
+      PathHtml=`echo $OUT_D/$htmlopt | sed -e 's:/modfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'`
       echo NOUVEL ATLAS DISPONIBLE SUR $PathHtml | tee >>  atlas.sh.log
       echo NOUVEL ATLAS DISPONIBLE SUR $PathHtml
Index: BOL/Multi_atlas/atlas/atlas.sh
===================================================================
--- BOL/Multi_atlas/atlas/atlas.sh	(revision 3736)
+++ BOL/Multi_atlas/atlas/atlas.sh	(revision 3737)
@@ -14,7 +14,127 @@
 login=aidelkad
 DODSDIR=/prodigfs/ipslfs/dods
-hostname=`hostname`
+#PBS -N atlas
+#PBS -m a
+#PBS -j oe
+#PBS -q h12
+#PBS -o atlasNOMSIMULATION.out
+#PBS -S /bin/bash
+#PBS -l nodes=1:ppn=1
+#PBS -l mem=30gb
+#PBS -l vmem=30gb
+#
+# Commande pour soumettre en bash
+submit=qsub
+
+login=aidelkad
+DODSDIR=/modfs/ipslfs/dods
+#PBS -N atlas
+#PBS -m a
+#PBS -j oe
+#PBS -q h12
+#PBS -o atlasNOMSIMULATION.out
+#PBS -S /bin/bash
+#PBS -l nodes=1:ppn=1
+#PBS -l mem=30gb
+#PBS -l vmem=30gb
+#
+# Commande pour soumettre en bash
+submit=qsub
+
+login=aidelkad
+DODSDIR=/modfs/ipslfs/dods
+#PBS -N atlas
+#PBS -m a
+#PBS -j oe
+#PBS -q h12
+#PBS -o atlasNOMSIMULATION.out
+#PBS -S /bin/bash
+#PBS -l nodes=1:ppn=1
+#PBS -l mem=30gb
+#PBS -l vmem=30gb
+#
+# Commande pour soumettre en bash
+submit=qsub
+
+login=aidelkad
+DODSDIR=/modfs/ipslfs/dods
+#PBS -N atlas
+#PBS -m a
+#PBS -j oe
+#PBS -q h12
+#PBS -o atlasNOMSIMULATION.out
+#PBS -S /bin/bash
+#PBS -l nodes=1:ppn=1
+#PBS -l mem=30gb
+#PBS -l vmem=30gb
+#
+# Commande pour soumettre en bash
+submit=qsub
+
+login=aidelkad
+DODSDIR=/modfs/ipslfs/dods
+#PBS -N atlas
+#PBS -m a
+#PBS -j oe
+#PBS -q h12
+#PBS -o atlasNOMSIMULATION.out
+#PBS -S /bin/bash
+#PBS -l nodes=1:ppn=1
+#PBS -l mem=30gb
+#PBS -l vmem=30gb
+#
+# Commande pour soumettre en bash
+submit=qsub
+
+login=aidelkad
+DODSDIR=/modfs/ipslfs/dods
+#PBS -N atlas
+#PBS -m a
+#PBS -j oe
+#PBS -q h12
+#PBS -o atlasNOMSIMULATION.out
+#PBS -S /bin/bash
+#PBS -l nodes=1:ppn=1
+#PBS -l mem=30gb
+#PBS -l vmem=30gb
+#
+# Commande pour soumettre en bash
+submit=qsub
+
+login=aidelkad
+DODSDIR=/modfs/ipslfs/dods
+#PBS -N atlas
+#PBS -m a
+#PBS -j oe
+#PBS -q h12
+#PBS -o atlasNOMSIMULATION.out
+#PBS -S /bin/bash
+#PBS -l nodes=1:ppn=1
+#PBS -l mem=30gb
+#PBS -l vmem=30gb
+#
+# Commande pour soumettre en bash
+submit=qsub
+
+login=aidelkad
+DODSDIR=/modfs/ipslfs/dods
+#PBS -N atlas
+#PBS -m a
+#PBS -j oe
+#PBS -q h12
+#PBS -o atlasNOMSIMULATION.out
+#PBS -S /bin/bash
+#PBS -l nodes=1:ppn=1
+#PBS -l mem=30gb
+#PBS -l vmem=30gb
+#
+# Commande pour soumettre en bash
+submit=qsub
+
+login=aidelkad
+DODSDIR=/modfs/ipslfs/dods
 # Definitions en fonction de la machine
 # CICLAD
+hostname=`hostname`
 if [ ${hostname:0:5} = cicla ] ; then
 ########################################################################################################
@@ -31,7 +151,7 @@
 MULTIDIR=$DODSDIR/$login/lmdz/MultiSimu
 DIRATLAS=$DODSDIR/$login/lmdz/atlas
+########################################################################################################
 ATLAS_DIR=$DODSDIR/$login/lmdz/atlas/Atlas$$
 if [ ! -d $DODSDIR/$login/lmdz/atlas/Atlas$$ ] ; then mkdir -p $DODSDIR/$login/lmdz/atlas/Atlas$$ ; fi
-##########################################################################################################
 fi
 local=`pwd -P`
@@ -149,7 +269,7 @@
       ls -lrt | tail
 # A ADAPTER en fonction de la machine
-      sed -e "s:/prodigfs/ipslfs/dods/:/thredds/fileServer/IPSLFS/:g" tmp$$.$passage >| $htmlopt
+      sed -e "s:/modfs/ipslfs/dods/:/thredds/fileServer/IPSLFS/:g" tmp$$.$passage >| $htmlopt
       \cp -f $htmlopt $OUT_D/
-      PathHtml=`echo $OUT_D/$htmlopt | sed -e 's:/prodigfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'`
+      PathHtml=`echo $OUT_D/$htmlopt | sed -e 's:/modfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'`
       echo NOUVEL ATLAS DISPONIBLE SUR $PathHtml | tee >>  atlas.sh.log
       echo NOUVEL ATLAS DISPONIBLE SUR $PathHtml
Index: BOL/Multi_atlas/cmor.sh
===================================================================
--- BOL/Multi_atlas/cmor.sh	(revision 3736)
+++ BOL/Multi_atlas/cmor.sh	(revision 3737)
@@ -16,9 +16,9 @@
 hostname=`hostname`
 if [ ${hostname:0:5} = cicla ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 OBSDIR=$DODSDIR/fabric/lmdz/SE/CMOR/OBS
 fi
 if [ ${hostname:0:5} = camel ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 OBSDIR=$DODSDIR/fabric/lmdz/SE/CMOR/OBS
 fi
Index: BOL/Multi_atlas/concat_html.sh
===================================================================
--- BOL/Multi_atlas/concat_html.sh	(revision 3736)
+++ BOL/Multi_atlas/concat_html.sh	(revision 3737)
@@ -28,5 +28,5 @@
 <table>
 
-<h1> $2 <A HREF=`echo $PNG_D/index.pdf | sed -e 's:/prodigfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'`> PDF </A></h1>
+<h1> $2 <A HREF=`echo $PNG_D/index.pdf | sed -e 's:/modfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'`> PDF </A></h1>
 eod
 
@@ -39,5 +39,5 @@
        file=$PNG_D/${vv}.png
        if [ -f $file ] ; then
-          thredds=`echo $file | sed -e 's:/prodigfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'`
+          thredds=`echo $file | sed -e 's:/modfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'`
           echo '<TD ALIGN=CENTER><A HREF="'$thredds'"><IMG HEIGHT=250 WIDTH=350 SRC="'$thredds'"></a></TD>'
        else
Index: BOL/Multi_atlas/html_accueil.sh
===================================================================
--- BOL/Multi_atlas/html_accueil.sh	(revision 3736)
+++ BOL/Multi_atlas/html_accueil.sh	(revision 3737)
@@ -6,10 +6,10 @@
 hostname=`hostname`
 if [ ${hostname:0:5} = cicla ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 HTML=http://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/$login/lmdz/MultiSimu/$comp
 machine=ciclad
 fi
 if [ ${hostname:0:5} = camel ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 fi
 if [ ${hostname:0:5} = irene ] ; then
@@ -36,4 +36,4 @@
 
 # ATTENTION A MODIFIER POUR D AUTRES MACHINE
-echo $compf | sed -e 's:/prodigfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'
+echo $compf | sed -e 's:/modfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'
 
Index: BOL/Multi_atlas/html_axe1.sh
===================================================================
--- BOL/Multi_atlas/html_axe1.sh	(revision 3736)
+++ BOL/Multi_atlas/html_axe1.sh	(revision 3737)
@@ -8,10 +8,10 @@
 hostname=`hostname`
 if [ ${hostname:0:5} = cicla ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 HTML00=http://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/$login
 machine=ciclad
 fi
 if [ ${hostname:0:5} = camel ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 fi
 if [ ${hostname:0:5} = irene ] ; then
@@ -99,4 +99,4 @@
 
 # A REFAIRE
-echo $compf | sed -e 's:/prodigfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'
+echo $compf | sed -e 's:/modfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'
 
Index: BOL/Multi_atlas/html_axe2.sh
===================================================================
--- BOL/Multi_atlas/html_axe2.sh	(revision 3736)
+++ BOL/Multi_atlas/html_axe2.sh	(revision 3737)
@@ -7,10 +7,10 @@
 hostname=`hostname`
 if [ ${hostname:0:5} = cicla ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 HTML00=http://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/$login
 machine=ciclad
 fi
 if [ ${hostname:0:5} = camel ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 fi
 if [ ${hostname:0:5} = irene ] ; then
@@ -59,3 +59,3 @@
 
 # A REFAIRE
-echo $compf | sed -e 's:/prodigfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'
+echo $compf | sed -e 's:/modfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'
Index: BOL/Multi_atlas/html_axe3.sh
===================================================================
--- BOL/Multi_atlas/html_axe3.sh	(revision 3736)
+++ BOL/Multi_atlas/html_axe3.sh	(revision 3737)
@@ -8,10 +8,10 @@
 hostname=`hostname`
 if [ ${hostname:0:5} = cicla ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 HTML00=http://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/$login
 machine=ciclad
 fi
 if [ ${hostname:0:5} = camel ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 fi
 if [ ${hostname:0:5} = irene ] ; then
@@ -128,3 +128,3 @@
 $local/concat_html.sh $COMP_D/REG "Regimes dynamiques tropicaux" $concatarg 3 >> $COMP_D/REG/index.html
 
-echo $compf | sed -e 's:/prodigfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'
+echo $compf | sed -e 's:/modfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'
Index: BOL/Multi_atlas/html_axe4.sh
===================================================================
--- BOL/Multi_atlas/html_axe4.sh	(revision 3736)
+++ BOL/Multi_atlas/html_axe4.sh	(revision 3737)
@@ -7,10 +7,10 @@
 hostname=`hostname`
 if [ ${hostname:0:5} = cicla ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 HTML00=http://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/$login
 machine=ciclad
 fi
 if [ ${hostname:0:5} = camel ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 fi
 if [ ${hostname:0:5} = irene ] ; then
@@ -95,4 +95,4 @@
 
 
-echo $compf | sed -e 's:/prodigfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'
+echo $compf | sed -e 's:/modfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'
 
Index: BOL/Multi_atlas/html_axe5.sh
===================================================================
--- BOL/Multi_atlas/html_axe5.sh	(revision 3736)
+++ BOL/Multi_atlas/html_axe5.sh	(revision 3737)
@@ -7,10 +7,10 @@
 hostname=`hostname`
 if [ ${hostname:0:5} = cicla ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 HTML00=http://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/$login
 machine=ciclad
 fi
 if [ ${hostname:0:5} = camel ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 fi
 if [ ${hostname:0:5} = irene ] ; then
@@ -46,4 +46,4 @@
 eod
 
-echo $compf | sed -e 's:/prodigfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'
+echo $compf | sed -e 's:/modfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'
 
Index: BOL/Multi_atlas/html_axe6.sh
===================================================================
--- BOL/Multi_atlas/html_axe6.sh	(revision 3736)
+++ BOL/Multi_atlas/html_axe6.sh	(revision 3737)
@@ -7,10 +7,10 @@
 hostname=`hostname`
 if [ ${hostname:0:5} = cicla ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 HTML00=http://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/$login
 machine=ciclad
 fi
 if [ ${hostname:0:5} = camel ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 fi
 if [ ${hostname:0:5} = irene ] ; then
@@ -45,3 +45,3 @@
 
 
-echo $compf | sed -e 's:/prodigfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'
+echo $compf | sed -e 's:/modfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'
Index: BOL/Multi_atlas/html_axe7.sh
===================================================================
--- BOL/Multi_atlas/html_axe7.sh	(revision 3736)
+++ BOL/Multi_atlas/html_axe7.sh	(revision 3737)
@@ -8,10 +8,10 @@
 hostname=`hostname`
 if [ ${hostname:0:5} = cicla ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 HTML00=http://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/$login
 machine=ciclad
 fi
 if [ ${hostname:0:5} = camel ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 fi
 if [ ${hostname:0:5} = irene ] ; then
@@ -128,3 +128,3 @@
 
 
-echo $compf | sed -e 's:/prodigfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'
+echo $compf | sed -e 's:/modfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'
Index: BOL/Multi_atlas/html_entete.sh
===================================================================
--- BOL/Multi_atlas/html_entete.sh	(revision 3736)
+++ BOL/Multi_atlas/html_entete.sh	(revision 3737)
@@ -8,10 +8,10 @@
 hostname=`hostname`
 if [ ${hostname:0:5} = cicla ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 HTML00=http://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/$login
 machine=ciclad
 fi
 if [ ${hostname:0:5} = camel ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 fi
 if [ ${hostname:0:5} = irene ] ; then
Index: BOL/Multi_atlas/html_tuning.sh
===================================================================
--- BOL/Multi_atlas/html_tuning.sh	(revision 3736)
+++ BOL/Multi_atlas/html_tuning.sh	(revision 3737)
@@ -7,10 +7,10 @@
 hostname=`hostname`
 if [ ${hostname:0:5} = cicla ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 HTML00=http://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/$login
 machine=ciclad
 fi
 if [ ${hostname:0:5} = camel ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 fi
 if [ ${hostname:0:5} = irene ] ; then
Index: BOL/Multi_atlas/html_tuning_min.sh
===================================================================
--- BOL/Multi_atlas/html_tuning_min.sh	(revision 3736)
+++ BOL/Multi_atlas/html_tuning_min.sh	(revision 3737)
@@ -7,10 +7,10 @@
 hostname=`hostname`
 if [ ${hostname:0:5} = cicla ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 HTML00=http://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/$login
 machine=ciclad
 fi
 if [ ${hostname:0:5} = camel ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 fi
 if [ ${hostname:0:5} = irene ] ; then
Index: BOL/Multi_atlas/install_multi_atlas.sh
===================================================================
--- BOL/Multi_atlas/install_multi_atlas.sh	(revision 3736)
+++ BOL/Multi_atlas/install_multi_atlas.sh	(revision 3737)
@@ -27,5 +27,5 @@
 if [ ${hostname:0:5} = cicla ] ; then
 # chemin vers le rep dods de base
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 # Rep ou sont stockes les multiatlas
 MULTIDIR=$DODSDIR/$login/lmdz/MultiSimu
@@ -54,5 +54,5 @@
 # CLIMSERV
 if [ ${hostname:0:5} = camel ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 cat <<eod > entete.sh
 #PBS -N atlas
@@ -135,16 +135,19 @@
 local=`pwd -P`
 
-echo -e "${noir}%%%%%%%%%%%%%%%%%%%%%%%%% ${rougefonce} MULTIATLAS LMDZ ${noir}%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%"
-echo -e "${vertfonce}" To create your multi-atlas you needs :
+echo -e "${noir}%%%%%%%%%%%%%%%%%%%%%%% ${rougefonce} LMDZ MULTIATLAS ${noir}%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%"
+echo
+echo -e "${vertfonce}"To create your multi-atlas you needs :
 echo 1.  to create your multiatlas directory "example Multi01" :
-echo    - mkdir -p /prodigfs/ipslfs/dods/$login/lmdz/MultiSimu/Multi01
+echo     mkdir -p /modfs/ipslfs/dods/$login/lmdz/MultiSimu/Multi01
+echo  
 echo 2.  to define some characeristics of your multi-atlas "names, dates, description of simulations and atlas variables" :
-echo    - cp Utils/def.txt  Utils/atlas-def /prodigfs/ipslfs/dods/$login/lmdz/MultiSimu/Multi01/.
+echo     cp Utils/def.txt  Utils/atlas-def /modfs/ipslfs/dods/$login/lmdz/MultiSimu/Multi01/.
 echo     define "names, date, description" of simulations in file :
-echo    - /prodigfs/ipslfs/dods/$login/lmdz/MultiSimu/Multi01/def.txt
-echo     define atlas variables in file
-echo    - /prodigfs/ipslfs/dods/$login/lmdz/MultiSimu/Multi01/atlas-def
+echo     /modfs/ipslfs/dods/$login/lmdz/MultiSimu/Multi01/def.txt
+echo     define atlas variables in file :
+echo     /modfs/ipslfs/dods/$login/lmdz/MultiSimu/Multi01/atlas-def
+echo
 echo 3.   Add the link to the simulation outputs in your file : $local/runs.txt
-
+echo 
 rm -f job_multi.sh
 cat entete.sh >| job_multi.sh 
@@ -160,3 +163,3 @@
 echo 4. Then you can run your multiatlas :
 echo ./job_multi.sh Multi01
-echo -e "${noir}%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%"
+echo -e "${noir}%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%"
Index: BOL/Multi_atlas/make_MOY.sh
===================================================================
--- BOL/Multi_atlas/make_MOY.sh	(revision 3736)
+++ BOL/Multi_atlas/make_MOY.sh	(revision 3737)
@@ -22,10 +22,10 @@
 hostname=`hostname`
 if [ ${hostname:0:5} = cicla ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 OBSDIR=$DODSDIR/fabric/lmdz
 ferret="/opt/ferret-7.0.0/bin/ferret"
 fi
 if [ ${hostname:0:5} = camel ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 OBSDIR=$DODSDIR/$login/lmdz
 ferret="/opt/ferret-7.0.0/bin/ferret"
Index: BOL/Multi_atlas/make_html_libigcm.sh
===================================================================
--- BOL/Multi_atlas/make_html_libigcm.sh	(revision 3736)
+++ BOL/Multi_atlas/make_html_libigcm.sh	(revision 3737)
@@ -55,10 +55,10 @@
 hostname=`hostname`
 if [ ${hostname:0:5} = cicla ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 HTML=http://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/$login/lmdz/MultiSimu/$comp
 machine=ciclad
 fi
 if [ ${hostname:0:5} = camel ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 fi
 if [ ${hostname:0:5} = irene ] ; then
@@ -88,5 +88,5 @@
 STORAGE=$CICLAD
 ROOTWEBatlas=http://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/$login/lmdz/STORE/$EXPNAME
-MULTIDIR=/prodigfs/ipslfs/dods/$login/lmdz/MultiSimu
+MULTIDIR=/modfs/ipslfs/dods/$login/lmdz/MultiSimu
 COMP_D=$MULTIDIR/$comp
 DEF_FILE=$COMP_D/def.txt
@@ -210,5 +210,5 @@
                  fi
 # ATTENTION A REFAIRE EN FONCTION DE LA MACHINE
-                 atlas_html=`echo $atlasf | sed -e 's:/prodigfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'`
+                 atlas_html=`echo $atlasf | sed -e 's:/modfs/ipslfs/dods/:http\://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/:'`
                  echo atlas_html $atlas_html
                  echo atlasf $atlasf
Index: BOL/Multi_atlas/mk_clouds_NOcalipso.sh
===================================================================
--- BOL/Multi_atlas/mk_clouds_NOcalipso.sh	(revision 3736)
+++ BOL/Multi_atlas/mk_clouds_NOcalipso.sh	(revision 3737)
@@ -8,8 +8,8 @@
 hostname=`hostname`
 if [ ${hostname:0:5} = cicla ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 fi
 if [ ${hostname:0:5} = camel ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 fi
 if [ ${hostname:0:5} = irene ] ; then
@@ -20,5 +20,5 @@
 fi
 
-###cd /prodigfs/ipslfs/dods/fabric/lmdz/VLR/DJF/OBS/ZON
+###cd /modfs/ipslfs/dods/fabric/lmdz/VLR/DJF/OBS/ZON
 if [ ! -d $DODSDIR/$login/lmdz/VLR/$SE/OBS/$TG ] ; then 
    mkdir -p $DODSDIR/$login/lmdz/VLR/$SE/OBS/$TG 
Index: BOL/Multi_atlas/multi_ZONE.sh
===================================================================
--- BOL/Multi_atlas/multi_ZONE.sh	(revision 3736)
+++ BOL/Multi_atlas/multi_ZONE.sh	(revision 3737)
@@ -14,8 +14,8 @@
 hostname=`hostname`
 if [ ${hostname:0:5} = cicla ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 fi
 if [ ${hostname:0:5} = camel ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 fi
 if [ ${hostname:0:5} = irene ] ; then
Index: BOL/Multi_atlas/multi_atlas.sh
===================================================================
--- BOL/Multi_atlas/multi_atlas.sh	(revision 3736)
+++ BOL/Multi_atlas/multi_atlas.sh	(revision 3737)
@@ -21,9 +21,9 @@
 hostname=`hostname`
 if [ ${hostname:0:5} = cicla ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 HTML=http://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/$login/lmdz/MultiSimu/$comp
 fi
 if [ ${hostname:0:5} = camel ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 fi
 if [ ${hostname:0:5} = irene ] ; then
Index: BOL/Multi_atlas/season.sh
===================================================================
--- BOL/Multi_atlas/season.sh	(revision 3736)
+++ BOL/Multi_atlas/season.sh	(revision 3737)
@@ -12,8 +12,8 @@
 hostname=`hostname`
 if [ ${hostname:0:5} = cicla ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 fi
 if [ ${hostname:0:5} = camel ] ; then
-DODSDIR=/prodigfs/ipslfs/dods
+DODSDIR=/modfs/ipslfs/dods
 fi
 if [ ${hostname:0:5} = irene ] ; then
@@ -49,5 +49,5 @@
      "-s") listesim=`echo $2 | sed -e 's/,/ /g'` ; shift ; shift ;;
      "-f") force_create=1 ; shift ;;
-     "-comp") COMP_D=/prodigfs/ipslfs/dods/fabric/lmdz/MultiSimu/$2 ; shift ; shift ;;
+     "-comp") COMP_D=/modfs/ipslfs/dods/fabric/lmdz/MultiSimu/$2 ; shift ; shift ;;
      "-seas") listeseas=$2 ; shift ; shift ;;
      *) ./cmor.sh -h ; shift ; exit ;;
Index: BOL/Multi_atlas/webpage_multi.sh
===================================================================
--- BOL/Multi_atlas/webpage_multi.sh	(revision 3737)
+++ BOL/Multi_atlas/webpage_multi.sh	(revision 3737)
@@ -0,0 +1,32 @@
+#!/bin/bash
+
+#set -v
+# Definition des coleurs d'affichage
+noir='\e[0;30m' gris='\e[1;30m' rougefonce='\e[0;31m' rose='\e[1;31m' vertfonce='\e[0;32m' vertclair='\e[1;32m' orange='\e[0;33m' jaune='\e[1;33m' bleufonce='\e[0;34m' bleuclair='\e[1;34m' violetfonce='\e[0;35m' violetclair='\e[1;35m' cyanfonce='\e[0;36m' cyanclair='\e[1;36m' grisclair='\e[0;37m' blanc='\e[1;37m' neutre='\e[0;m'
+
+
+login=`whoami`
+
+comp=$1
+
+hostname=`hostname`
+if [ ${hostname:0:5} = cicla ] ; then
+DODSDIR=/modfs/ipslfs/dods
+HTML=http://vesg.ipsl.upmc.fr/thredds/fileServer/IPSLFS/$login/lmdz/MultiSimu/$comp
+fi
+if [ ${hostname:0:5} = camel ] ; then
+DODSDIR=/modfs/ipslfs/dods
+fi
+if [ ${hostname:0:5} = irene ] ; then
+DODSDIR=
+fi
+if [ ${hostname:0:5} = jean- ] ; then
+DODSDIR=
+fi
+
+echo -e "${vertfonce}YOUR MULTIATLAS IS AVAILABLE ON THE PAGE: : "
+rm -f tmp_web.txt
+cat <<  eod >> tmp_web.txt
+$HTML/ACCUEIl.html
+eod
+cat tmp_web.txt

Index: BOL/Multi_atlas/Utils/multi.sh
===================================================================
--- BOL/Multi_atlas/Utils/multi.sh	(revision 3736)
+++ BOL/Multi_atlas/Utils/multi.sh	(revision 3737)
@@ -97,5 +97,5 @@
    echo             ou le meme nom est attribue a plusieures simulations
    echo Il faut la rajouter dans $runstxt 
-   echo avec le chemin vers les SE et TS dans ciclad : /prodigfs/$login/IGCM_OUT
+   echo avec le chemin vers les SE et TS dans ciclad : /modfs/$login/IGCM_OUT
    echo             ou renomer votre simulation
 exit
@@ -159,6 +159,6 @@
 #########################################################################
 # Deux lignes suivantes modif FH 2016/11/09
 # Files are taken from /prodigfs/ipslfs/dods/fabric/lmdz/SE/ORIG and
 # results are in /prodigfs/ipslfs/dods/fabric/lmdz/SE/CMOR
 #########################################################################
  ./cmor.sh -runsfile $runstxt $comp
@@ -170,5 +170,5 @@
 #     average in time "YEAR", "JJA" ...
 #     Results are put on
-#     /prodigfs/ipslfs/dods/fabric/lmdz/VLR/YEAR/[SIMU_NAME]_[period]/NC
+#     /modfs/ipslfs/dods/fabric/lmdz/VLR/YEAR/[SIMU_NAME]_[period]/NC
 #     If wanting to rerun season.sh for observations :
 #     ./season.sh -s OBS
@@ -402,3 +402,3 @@
 fi
 
-echo UN NOVEL MULTI ATLAS EST DISPONIBLE sur $COMP_D/ACCUEIL.html
+./webpage_multi.sh $comp
@@ -159,6 +159,6 @@
 #########################################################################
 # Deux lignes suivantes modif FH 2016/11/09
-# Files are taken from /prodigfs/ipslfs/dods/fabric/lmdz/SE/ORIG and
-# results are in /prodigfs/ipslfs/dods/fabric/lmdz/SE/CMOR
+# Files are taken from /modfs/ipslfs/dods/fabric/lmdz/SE/ORIG and
+# results are in /modfs/ipslfs/dods/fabric/lmdz/SE/CMOR
 #########################################################################
  ./cmor.sh -runsfile $runstxt $comp